About
=====

Mangling of various file formats that conveys binary information
(Motorola S-Record, Intel HEX, TI-TXT, Verilog VMEM, ELF and binary
files).

Project homepage: https://github.com/eerimoq/moblin_assistant

Installation
============

.. code-block:: python

    pip install moblin_assistant

Example usage
=============

Terminal 1.

.. code-block:: text

   $ moblin_assistant run

Terminal 2.

.. code-block:: text

   $ moblin_assistant set_scene Back
